==> aria2-1.3.3.tar.bz2: aria2-1.3.3/src/DHTGetPeersReplyMessage.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DHT_GET_PEERS_REPLY_MESSAGE_H_
#define _D_DHT_GET_PEERS_REPLY_MESSAGE_H_

#include "DHTResponseMessage.h"

#include <deque>

#include "DHTConstants.h"

namespace aria2 {

class Peer;

class DHTGetPeersReplyMessage:public DHTResponseMessage {
private:
  std::string _token;

  std::deque<SharedHandle<DHTNode> > _closestKNodes;

  std::deque<SharedHandle<Peer> > _values;
protected:
  virtual std::string toStringOptional() const;
public:
  DHTGetPeersReplyMessage(const SharedHandle<DHTNode>& localNode,
			  const SharedHandle<DHTNode>& remoteNode,
			  const std::string& token,
			  const std::string& transactionID);

  virtual ~DHTGetPeersReplyMessage();

  virtual void doReceivedAction();

  virtual BDE getResponse();

  virtual std::string getMessageType() const;

  virtual void validate() const;

  const std::deque<SharedHandle<DHTNode> >& getClosestKNodes() const;

  const std::deque<SharedHandle<Peer> >& getValues() const;

  void setClosestKNodes(const std::deque<SharedHandle<DHTNode> >& closestKNodes);

  void setValues(const std::deque<SharedHandle<Peer> >& peers);
  
  const std::string& getToken() const
  {
    return _token;
  }

  static const std::string GET_PEERS;

  static const std::string TOKEN;

  static const std::string VALUES;

  static const std::string NODES;
};

} // namespace aria2

#endif // _D_DHT_GET_PEERS_REPLY_MESSAGE_H_

==> aria2-1.9.1.tar.bz2: aria2-1.9.1/src/DHTGetPeersReplyMessage.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DHT_GET_PEERS_REPLY_MESSAGE_H_
#define _D_DHT_GET_PEERS_REPLY_MESSAGE_H_

#include "DHTResponseMessage.h"

#include <vector>

#include "DHTConstants.h"

namespace aria2 {

class Peer;

class DHTGetPeersReplyMessage:public DHTResponseMessage {
private:
  std::string _token;

  std::vector<SharedHandle<DHTNode> > _closestKNodes;

  std::vector<SharedHandle<Peer> > _values;
protected:
  virtual std::string toStringOptional() const;
public:
  DHTGetPeersReplyMessage(const SharedHandle<DHTNode>& localNode,
                          const SharedHandle<DHTNode>& remoteNode,
                          const std::string& token,
                          const std::string& transactionID);

  virtual ~DHTGetPeersReplyMessage();

  virtual void doReceivedAction();

  virtual BDE getResponse();

  virtual std::string getMessageType() const;

  virtual void validate() const;

  const std::vector<SharedHandle<DHTNode> >& getClosestKNodes() const
  {
    return _closestKNodes;
  }

  const std::vector<SharedHandle<Peer> >& getValues() const
  {
    return _values;
  }

  void setClosestKNodes
  (const std::vector<SharedHandle<DHTNode> >& closestKNodes)
  {
    _closestKNodes = closestKNodes;
  }

  void setValues(const std::vector<SharedHandle<Peer> >& peers)
  {
    _values = peers;
  }
  
  const std::string& getToken() const
  {
    return _token;
  }

  static const std::string GET_PEERS;

  static const std::string TOKEN;

  static const std::string VALUES;

  static const std::string NODES;
};

} // namespace aria2

#endif // _D_DHT_GET_PEERS_REPLY_MESSAGE_H_
